@@ -1,7 +1,7 @@
 # IMPORT LIBRARIES
 import os
 from io import BytesIO
-from requests import get as requests_get
+import urllib.request
 from PIL import Image as PIL_Image, ImageTk as PIL_ImageTk
 import tkinter as TK
 import threading, math, time
@@ -554,7 +554,8 @@ class Image_Lite:
                 return
             Data=None
             if self._Url and self._Path:
-                Data=requests_get(self._Path).content
+                with urllib.request.urlopen(self._Path) as response:
+                    Data = response.read()
             elif self._Path and os.path.exists(self._Path):
                 with open(self._Path,"rb") as F:
                     Data=F.read()
